@@ -12,6 +12,7 @@ from .loop import loop
 from fastapi_utils.tasks import repeat_every
 import logging
 from uuid import uuid4
+from learning_loop_node.decorators.error_handler import try_except
 
 
 class Node(FastAPI):
@@ -22,9 +23,7 @@ class Node(FastAPI):
         super().__init__()
         host = os.environ.get('LOOP_HOST', None) or os.environ.get('HOST', 'learning-loop.ai')
         self.ws_url = f'ws{"s" if host != "backend" else ""}://' + host
-        self.organization = os.environ.get('LOOP_ORGANIZATION', None) or os.environ.get('ORGANIZATION', None)
-        self.project = os.environ.get('LOOP_PROJECT', None) or os.environ.get('PROJECT', None)
-
+     
         self.name = name
         self.uuid = self.read_or_create_uuid() if uuid is None else uuid
 
@@ -33,6 +32,7 @@ class Node(FastAPI):
             request_timeout=0.5,
             # logger=True, engineio_logger=True
         )
+        self.sio_client._trigger_event = try_except(self.sio_client._trigger_event)
         self.reset()
 
         @self.sio_client.on('connect')
