@@ -18,7 +18,7 @@ class TrainerNode(Node):
     latest_known_model_id: Union[str, None]
     skip_check_state: bool = False
 
-    def __init__(self, name: str, uuid: str, trainer: Trainer):
+    def __init__(self, name: str, trainer: Trainer, uuid: str = None):
         super().__init__(name, uuid)
         self.trainer = trainer
         self.latest_known_model_id = None
@@ -43,7 +43,10 @@ class TrainerNode(Node):
         @repeat_every(seconds=5, raise_exceptions=True, wait_first=False)
         async def check_state():
             if not self.skip_check_state:
-                await self.check_state()
+                try:
+                    await self.check_state()
+                except:
+                    logging.exception('could not check state')
 
     async def begin_training(self, context: Context, source_model: dict):
         self.status.latest_error = None
@@ -106,8 +109,8 @@ class TrainerNode(Node):
                         id=str(uuid4()),
                         confusion_matrix=model.confusion_matrix,
                         parent_id=self.latest_known_model_id,
-                        train_image_count=self.trainer.training.data.train_image_count(),
-                        test_image_count=self.trainer.training.data.test_image_count(),
+                        train_image_count=current_training.data.train_image_count(),
+                        test_image_count=current_training.data.test_image_count(),
                         trainer_id=self.uuid,
                     )
 
@@ -134,6 +137,11 @@ class TrainerNode(Node):
             latest_error=self.status.latest_error
         )
 
+        if self.trainer and self.trainer.training:
+            status.train_image_count = self.trainer.training.data.train_image_count()
+            status.test_image_count = self.trainer.training.data.test_image_count()
+            status.skipped_image_count = self.trainer.training.data.skipped_image_count
+
         logging.info(f'sending status {status}')
         result = await self.sio_client.call('update_trainer', jsonable_encoder(status), timeout=1)
         if not result == True:
